starcluster.templates.sge

Package starcluster :: Package templates :: Module sge |
[hide private]
[frames] | no frames]

# Module sge

source code

Variables | [hide private]
| sgeinstall_template = ``'``\nSGE_CLUSTER_NAME="starcluster"\nSGE_R``...``
| sge_pe_template = ``'``\npe_name %s\nslots %``...``
| sgeprofile_template = ``'``\nexport SGE_ROOT="/opt/sge6"\nexport S``...``
| __package__ = `None` hash(x)

Variables Details | [hide private]

  ### sgeinstall_template Value:
      '''
      SGE_CLUSTER_NAME="starcluster"
      SGE_ROOT="/opt/sge6"
      SGE_QMASTER_PORT="63231"
      SGE_EXECD_PORT="63232"
      SGE_ENABLE_SMF="false"
      CELL_NAME="default"
      ADMIN_USER=""
      ...

  ### sge_pe_template Value:
      '''
      pe_name           %s
      slots             %s
      user_lists        NONE
      xuser_lists       NONE
      start_proc_args   /bin/true
      stop_proc_args    /bin/true
      allocation_rule   $round_robin
      ...

  ### sgeprofile_template Value:
      '''
      export SGE_ROOT="/opt/sge6"
      export SGE_CELL="default"
      export SGE_CLUSTER_NAME="starcluster"
      export SGE_QMASTER_PORT="63231"
      export SGE_EXECD_PORT="63232"
      export MANTYPE="man"
      export MANPATH="$MANPATH:$SGE_ROOT/man"
      ...